@@ -1,10 +1,9 @@
 #ifndef _CAMKEY_H_
 #define _CAMKEY_H_
 
-//#include <glib.h>
-//#include <dbus/dbus-glib-lowlevel.h>
-//#include <dbus/dbus-glib.h>
-#include <dbus/dbus.h>
+#include <glib.h>
+#include <dbus/dbus-glib-lowlevel.h>
+#include <dbus/dbus-glib.h>
 #include <libhal.h>
 #include <string.h>
 #include <X11/Xlib.h>
