@@ -11,7 +11,7 @@
 #include "camkey.h"
 #include "proximity.h"
 #include "shortcutd.h"
-
+#include <fstream>
 extern "C"
 {
 #include "json/JSON_parser.h"
@@ -20,6 +20,7 @@ extern "C"
 class Config
 {
 	private:
+		const char* configDir;
 		const char* configFile;
 		FILE* input;
 		JSON_config config;
@@ -34,7 +35,7 @@ class Config
 
 		ProximitySensor* ps;
 		CameraKey* ck;
-		
+		void writeConfigFile();	
 		
 		
 	public:
@@ -42,6 +43,7 @@ class Config
 		~Config();
 		int readConfig();
 		int proximityOn;
+		int camerakeyOn;
 		void setProximity(ProximitySensor* ps_);
 		void setCameraKey(CameraKey* ck_);
 
